==> jc-1.4.0.tar.gz: java/net/ConnectException.h <==
// public class java.net.ConnectException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class dfb49fd65489a67f java_net_ConnectException
// @dep_class e1b77f50ab8f37ad java_net_SocketException

// header file dependencies
// @dep_header java_net_SocketException

#include "java/net/SocketException.h"

#ifndef _JC_java_net_ConnectException_H_
#define _JC_java_net_ConnectException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_net_ConnectException$sub_refs	_jc_java_net_ConnectException$sub_refs;
typedef struct _jc_java_net_ConnectException$sub_nonrefs	_jc_java_net_ConnectException$sub_nonrefs;
typedef struct _jc_java_net_ConnectException$refs	_jc_java_net_ConnectException$refs;
typedef struct _jc_java_net_ConnectException$nonrefs	_jc_java_net_ConnectException$nonrefs;
typedef struct _jc_java_net_ConnectException$object	_jc_java_net_ConnectException$object;

typedef struct _jc_java_net_ConnectException$fields_struct	_jc_java_net_ConnectException$fields_struct;
typedef const struct _jc_java_net_ConnectException$vmethods	_jc_java_net_ConnectException$vmethods;
typedef const struct _jc_java_net_ConnectException$vtable	_jc_java_net_ConnectException$vtable;
typedef const struct _jc_java_net_ConnectException$vtype	_jc_java_net_ConnectException$vtype;

// Class fields structure
struct _jc_java_net_ConnectException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_net_ConnectException$fields_struct _jc_java_net_ConnectException$class_fields;

// Constructors
extern void _jc_java_net_ConnectException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_net_ConnectException$object *);
extern void _jc_java_net_ConnectException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_net_ConnectException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_net_ConnectException$vmethods {
};

// Vtable
struct _jc_java_net_ConnectException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_net_SocketException$vmethods	java_net_SocketException;
	_jc_java_net_ConnectException$vmethods	java_net_ConnectException;
};

// Vtype
struct _jc_java_net_ConnectException$vtype {
	_jc_type			type;
	_jc_java_net_ConnectException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_ConnectException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_net_ConnectException$refs {
    _jc_java_net_ConnectException$sub_refs	java_net_ConnectException;
    _jc_java_net_SocketException$sub_refs	java_net_SocketException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_ConnectException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_net_ConnectException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_net_SocketException$sub_nonrefs	java_net_SocketException;
    _jc_java_net_ConnectException$sub_nonrefs	java_net_ConnectException;
};

// Object instance structure
struct _jc_java_net_ConnectException$object {
	_jc_java_net_ConnectException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_ConnectException$vtype	*vtype;
	_jc_java_net_ConnectException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_ConnectException$vtype _jc_java_net_ConnectException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_ConnectException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_ConnectException$class_object;

#endif	/* _JC_java_net_ConnectException_H_ */

==> jc-1.4.6.tar.gz: java/net/ConnectException.h <==
// public class java.net.ConnectException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class dfb49fd65489a67f java_net_ConnectException
// @dep_class e1b77f50ab8f37ad java_net_SocketException

// header file dependencies
// @dep_header java_net_SocketException

#include "java/net/SocketException.h"

#ifndef _JC_java_net_ConnectException_H_
#define _JC_java_net_ConnectException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_net_ConnectException$sub_refs	_jc_java_net_ConnectException$sub_refs;
typedef struct _jc_java_net_ConnectException$sub_nonrefs	_jc_java_net_ConnectException$sub_nonrefs;
typedef struct _jc_java_net_ConnectException$refs	_jc_java_net_ConnectException$refs;
typedef struct _jc_java_net_ConnectException$nonrefs	_jc_java_net_ConnectException$nonrefs;
typedef struct _jc_java_net_ConnectException$object	_jc_java_net_ConnectException$object;

typedef struct _jc_java_net_ConnectException$fields_struct	_jc_java_net_ConnectException$fields_struct;
typedef const struct _jc_java_net_ConnectException$vmethods	_jc_java_net_ConnectException$vmethods;
typedef const struct _jc_java_net_ConnectException$vtable	_jc_java_net_ConnectException$vtable;
typedef const struct _jc_java_net_ConnectException$vtype	_jc_java_net_ConnectException$vtype;

// Class fields structure
struct _jc_java_net_ConnectException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_net_ConnectException$fields_struct _jc_java_net_ConnectException$class_fields;

// Constructors
extern void _jc_java_net_ConnectException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_net_ConnectException$object *) _JC_JCNI_ATTR;
extern void _jc_java_net_ConnectException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_net_ConnectException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_net_ConnectException$vmethods {
};

// Vtable
struct _jc_java_net_ConnectException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_net_SocketException$vmethods	java_net_SocketException;
	_jc_java_net_ConnectException$vmethods	java_net_ConnectException;
};

// Vtype
struct _jc_java_net_ConnectException$vtype {
	_jc_type			type;
	_jc_java_net_ConnectException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_ConnectException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_net_ConnectException$refs {
    _jc_java_net_ConnectException$sub_refs	java_net_ConnectException;
    _jc_java_net_SocketException$sub_refs	java_net_SocketException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_ConnectException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_net_ConnectException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_net_SocketException$sub_nonrefs	java_net_SocketException;
    _jc_java_net_ConnectException$sub_nonrefs	java_net_ConnectException;
};

// Object instance structure
struct _jc_java_net_ConnectException$object {
	_jc_java_net_ConnectException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_ConnectException$vtype	*vtype;
	_jc_java_net_ConnectException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_ConnectException$vtype _jc_java_net_ConnectException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_ConnectException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_ConnectException$class_object;

#endif	/* _JC_java_net_ConnectException_H_ */
